<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.getfoundni.co.uk/
 * @since      1.0.0
 *
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/admin
 * @author     Ryan Hull <ryan@getfoundni.co.uk>
 */
class Notify_Gfni_Admin
{
    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;


    private $notify_settings_options;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/notify-gfni-admin.css', array(), $this->version, 'all');
        wp_enqueue_style('datatables-style', '//cdn.datatables.net/1.10.12/css/jquery.dataTables.min.css', array(), $this->version, 'all');
        wp_enqueue_style('datatables-style2', 'https://cdnjs.cloudflare.com/ajax/libs/semantic-ui/2.3.1/semantic.min.css', array(), $this->version, 'all');
        wp_enqueue_style('datatables-style3', 'https://cdn.datatables.net/1.10.23/css/dataTables.semanticui.min.css', array(), $this->version, 'all');
        wp_enqueue_style('fontawesome-regular', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.2/css/solid.min.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/notify-gfni-admin.js', array( 'jquery', 'wp-util'), $this->version, true);
        wp_enqueue_script('datatables', '//cdn.datatables.net/1.10.12/js/jquery.dataTables.min.js', array( 'jquery' ), $this->version, false);
        wp_enqueue_script('datatables2', 'https://cdn.datatables.net/1.10.23/js/dataTables.semanticui.min.js', array( 'jquery' ), $this->version, false);
        wp_enqueue_script('datatables3', 'https://cdnjs.cloudflare.com/ajax/libs/semantic-ui/2.3.1/semantic.min.js', array( 'jquery' ), $this->version, false);
        wp_enqueue_script('alpinejs', 'https://unpkg.com/alpinejs@3.x.x/dist/cdn.min.js', array(), $this->version, true);
    }

    public function plugin_setup_menu()
    {
        add_menu_page('Notify', 'Notify', 'manage_options', 'notify-plugin', [$this,'admin_content']);
        add_submenu_page('notify-plugin', 'Create Email', 'Create Notify Email', 'manage_options', 'notify-plugin-send', [$this,'admin_content']);
        add_submenu_page('notify-plugin', 'Options', 'Notify Options', 'manage_options', 'notify-plugin-options', [$this,'notify_settings_create_admin_page']);
        add_submenu_page('notify-plugin', 'Sub List', 'Notify List', 'manage_options', 'notify-plugin-list', [$this,'notify_sub_list_page']);
    }

    public function notify_sub_list_page()
    {
        ob_start();
        include_once plugin_dir_path(dirname(__FILE__)) . '/admin/partials/notify-gfni-admin-sublist.php';
        $t = ob_get_contents();
        ob_clean();
        echo $t;
    }

    public function admin_content()
    {
        ob_start();
        include_once plugin_dir_path(dirname(__FILE__)) . '/admin/partials/notify-gfni-admin-display.php';
        $t = ob_get_contents();
        ob_clean();
        echo $t;
    }


    public function notify_settings_create_admin_page()
    {
        wp_enqueue_media();
        $this->notify_settings_options = get_option('notify_settings_option_name'); ?>

		<div class="wrap">

			<form method="post" action="options.php">
				<div class="notify-card">
					<div class="notify-card-title">
						<img src="<?php echo plugin_dir_url(dirname(__FILE__)) ?>admin/assets/logo.png" alt="Notify by Get Found NI">
					</div>
					<div class="notify-card-subtitle"><h2>Notify - Settings</h2></div>
					<div class="notify-card-body">
							<p>Add the settings emailed to you here.</p>
							<div>
								<?php get_settings_errors(); ?>
							</div>
							<?php
                                settings_fields('notify_settings_option_group');
        do_settings_sections('notify-settings-admin');
        ?>
					</div>
					<div class="notify-card-footer"><?php submit_button(); ?></div>
				</div>
			</form>

		</div>
	<?php
    }


    /**
     * Register Page Settings
     *
     * @return void
     */
    public function notify_settings_page_init()
    {
        register_setting(
            'notify_settings_option_group', // option_group
            'notify_settings_option_name', // option_name
            array( $this, 'notify_settings_sanitize' ) // sanitize_callback
        );

        add_settings_section(
            'notify_settings_setting_section', // id
            'Settings', // title
            array( $this, 'notify_settings_section_info' ), // callback
            'notify-settings-admin' // page
        );

        add_settings_field(
            'key_0', // id
            'Key', // title
            array( $this, 'key_0_callback' ), // callback
            'notify-settings-admin', // page
            'notify_settings_setting_section' // section
        );

        add_settings_field(
            'from_email_1', // id
            'From Email', // title
            array( $this, 'from_email_1_callback' ), // callback
            'notify-settings-admin', // page
            'notify_settings_setting_section' // section
        );

        add_settings_field(
            'from_name_2', // id
            'From Name', // title
            array( $this, 'from_name_2_callback' ), // callback
            'notify-settings-admin', // page
            'notify_settings_setting_section' // section
        );


        add_settings_field(
            'show_subscribe_box_0', // id
            'Subscribe Box', // title
            array( $this, 'show_subscribe_box_0_callback' ), // callback
            'notify-settings-admin', // page
            'notify_settings_setting_section' // section
        );

        add_settings_field(
            'subscribe_box_label_1', // id
            'Subscribe Box Label', // title
            array( $this, 'subscribe_box_label_1_callback' ), // callback
            'notify-settings-admin', // page
            'notify_settings_setting_section' // section
        );

        add_settings_field(
            'from_name_3', // id
            'logo', // title
            array( $this, 'from_name_3_callback' ), // callback
            'notify-settings-admin', // page
            'notify_settings_setting_section' // section
        );
    }

    public function notify_settings_sanitize($input)
    {
        $sanitary_values = array();
        if (isset($input['key_0'])) {
            $sanitary_values['key_0'] = sanitize_text_field($input['key_0']);
        }

        if (isset($input['from_email_1'])) {
            $sanitary_values['from_email_1'] = sanitize_text_field($input['from_email_1']);
        }

        if (isset($input['from_name_2'])) {
            $sanitary_values['from_name_2'] = sanitize_text_field($input['from_name_2']);
        }

        if (isset($input['from_name_3'])) {
            $sanitary_values['from_name_3'] = $input['from_name_3'];
        }

        if (isset($input['show_subscribe_box_0'])) {
            $sanitary_values['show_subscribe_box_0'] = $input['show_subscribe_box_0'];
        }

        if (isset($input['subscribe_box_label_1'])) {
            $sanitary_values['subscribe_box_label_1'] = sanitize_text_field($input['subscribe_box_label_1']);
        }

        return $sanitary_values;
    }

    public function notify_settings_section_info()
    {
    }

    public function key_0_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="notify_settings_option_name[key_0]" id="key_0" value="%s">',
            is_array($this->notify_settings_options) && isset($this->notify_settings_options['key_0']) ? esc_attr($this->notify_settings_options['key_0']) : ''
        );
    }

    public function from_email_1_callback()
    {
        printf(
            '<input class="regular-text" type="text" placeholder="info@' . $_SERVER['SERVER_NAME'] . '" name="notify_settings_option_name[from_email_1]" id="from_email_1" value="%s"><br><small>This email address should be <strong>*****@' . $_SERVER['SERVER_NAME'] . '</strong></small>',
            is_array($this->notify_settings_options) && isset($this->notify_settings_options['from_email_1']) ? esc_attr($this->notify_settings_options['from_email_1']) : ''
        );
    }

    public function from_name_2_callback()
    {
        printf(
            '<input class="regular-text" type="text" placeholder="'.get_bloginfo('name').'" name="notify_settings_option_name[from_name_2]" id="from_name_2" value="%s">',
            is_array($this->notify_settings_options) && isset($this->notify_settings_options['from_name_2']) ? esc_attr($this->notify_settings_options['from_name_2']) : ''
        );
    }

    public function from_name_3_callback()
    {
        if (is_array($this->notify_settings_options) && $image = wp_get_attachment_image_src($this->notify_settings_options['from_name_3'])) {
            echo '<a href="#" class="misha-upl"><img src="' . $image[0] . '" /></a>
				  <a href="#" class="misha-rmv">Remove image</a>
				  <input id="from_name_3" type="hidden" name="notify_settings_option_name[from_name_3]" value="' . $this->notify_settings_options['from_name_3'] . '">';
        } else {
            echo '<a href="#" class="misha-upl">Upload image</a>
				  <a href="#" class="misha-rmv" style="display:none">Remove image</a>
				  <input id="from_name_3" type="hidden" name="notify_settings_option_name[from_name_3]" value="">';
        }
    }

    public function show_subscribe_box_0_callback()
    {
        printf(
            '<input type="checkbox" name="notify_settings_option_name[show_subscribe_box_0]" id="show_subscribe_box_0" value="show_subscribe_box_0" %s> <label for="show_subscribe_box_0">Hide the subscribe checkbox on the checkout page and subscribe all users.</label>',
            (isset($this->notify_settings_options['show_subscribe_box_0']) && $this->notify_settings_options['show_subscribe_box_0'] === 'show_subscribe_box_0') ? 'checked' : ''
        );
    }

    public function subscribe_box_label_1_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="notify_settings_option_name[subscribe_box_label_1]" id="subscribe_box_label_1" value="%s">',
            isset($this->notify_settings_options['subscribe_box_label_1']) ? esc_attr($this->notify_settings_options['subscribe_box_label_1']) : 'Signup for alerts?'
        );
    }

    public function notify_sync_contacts()
    {
        status_header(200);
        $users = get_users(array( 'role__in' => array( 'customer' ) ));
        $data = [];

        foreach ($users as $user) {
            $u = [];
            $u['email'] = $user->user_email;
            $u['first_name'] = $user->first_name;
            $u['last_name'] =  $user->last_name;
            $data[] = $u;
        }

        $url = 'https://notify.getfoundni.co.uk/api/sync';
        $key = get_option('notify_settings_option_name')['key_0'];

        $f = [];
        foreach (array_chunk($data, 500) as $chunk) {
            $c = [
                'key' 	=> $key,
                'users' => $chunk
            ];
            $f[] = $c;
        }

        echo json_encode($f);
        exit();
    }
}
