<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.getfoundni.co.uk/
 * @since      1.0.0
 *
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/includes
 * @author     Ryan Hull <ryan@getfoundni.co.uk>
 */
class Notify_Gfni
{

    /**
     * The loader that's responsible for maintaining and registering all hooks that power
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      Notify_Gfni_Loader    $loader    Maintains and registers all hooks for the plugin.
     */
    protected $loader;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $plugin_name    The string used to uniquely identify this plugin.
     */
    protected $plugin_name;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $version    The current version of the plugin.
     */
    protected $version;

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct()
    {
        if (defined('NOTIFY_GFNI_VERSION')) {
            $this->version = NOTIFY_GFNI_VERSION;
        } else {
            $this->version = '1.0.0';
        }
        $this->plugin_name = 'notify-gfni';

        $this->load_dependencies();
        $this->set_locale();
        $this->define_admin_hooks();
        $this->define_public_hooks();
    }

    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - Notify_Gfni_Loader. Orchestrates the hooks of the plugin.
     * - Notify_Gfni_i18n. Defines internationalization functionality.
     * - Notify_Gfni_Admin. Defines all hooks for the admin area.
     * - Notify_Gfni_Public. Defines all hooks for the public side of the site.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function load_dependencies()
    {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-notify-gfni-loader.php';

        /**
         * The class responsible for defining internationalization functionality
         * of the plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-notify-gfni-i18n.php';

        /**
         * The class responsible for defining all actions that occur in the admin area.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-notify-gfni-admin.php';

        /**
         * The class responsible for defining all actions that occur in the public-facing
         * side of the site.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-notify-gfni-public.php';

        $this->loader = new Notify_Gfni_Loader();
    }

    /**
     * Define the locale for this plugin for internationalization.
     *
     * Uses the Notify_Gfni_i18n class in order to set the domain and to register the hook
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function set_locale()
    {
        $plugin_i18n = new Notify_Gfni_i18n();

        $this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
    }

    /**
     * Register all of the hooks related to the admin area functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_admin_hooks()
    {
        $plugin_admin = new Notify_Gfni_Admin($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('admin_menu', $plugin_admin, 'plugin_setup_menu');
        $this->loader->add_action('admin_init', $plugin_admin, 'notify_settings_page_init');
        $this->loader->add_action('admin_post_notify_sync_contacts', $plugin_admin, 'notify_sync_contacts');
        $this->loader->add_action('wp_ajax_notify_sync_contacts', $plugin_admin, 'notify_sync_contacts');

        if (isset($_GET['page'])) {
            if ($_GET['page'] == 'notify-plugin' || $_GET['page'] == 'notify-plugin-send' || $_GET['page'] == 'notify-plugin-options' || $_GET['page'] == 'notify-plugin-list') {
                $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
                $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
            }
        }
    }

    /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_public_hooks()
    {
        $plugin_public = new Notify_Gfni_Public($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');

        //Custom Hooks
        $this->loader->add_action('woocommerce_after_order_notes', $plugin_public, 'notify_checkbox');
        $this->loader->add_action('woocommerce_checkout_process', $plugin_public, 'notify_checkbox_process');

        //Shortcode
        $this->loader->add_action('init', $plugin_public, 'register_shortcodes');
        //Api
        $this->loader->add_action('rest_api_init', $plugin_public, 'register_rest_api_routes');
    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run()
    {
        $this->loader->run();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function get_plugin_name()
    {
        return $this->plugin_name;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @since     1.0.0
     * @return    Notify_Gfni_Loader    Orchestrates the hooks of the plugin.
     */
    public function get_loader()
    {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public function get_version()
    {
        return $this->version;
    }
}
