<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.getfoundni.co.uk/
 * @since      1.0.0
 *
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/public
 * @author     Ryan Hull <ryan@getfoundni.co.uk>
 */
class Notify_Gfni_Public
{
    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/notify-gfni-public.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/notify-gfni-public.js', array( 'jquery' ), $this->version, false);
    }

    public function notify_checkbox($checkout)
    {
        $opt = get_option('notify_settings_option_name');
        if (!$opt || !$opt['key_0']) {
            return;
        }
        if ($opt['show_subscribe_box_0']) {
            woocommerce_form_field('notify_signup', array(
                'type'          => 'hidden'
            ), 1);
        } else {
            woocommerce_form_field('notify_signup', array(
                'type'          => 'checkbox',
                'label'         => !empty($opt['subscribe_box_label_1']) ? $opt['subscribe_box_label_1'] : 'Signup for alerts?',
                'checked'		=> true
            ), 1);
        }
    }

    public function notify_checkbox_process()
    {
        if ($_POST['notify_signup'] && !empty(get_option('notify_settings_option_name')['key_0'])) {
            $this->post_subscriber($_POST['billing_email'], $_POST['billing_first_name'], $_POST['billing_last_name']);
        }
    }

    public function register_shortcodes()
    {
        add_shortcode('notify-form', array( $this, 'notify_form'));
    }

    // Shortcode: [notify-form]
    public function notify_form()
    {
        ob_start(); ?>

            <div class="notify-form-wrapper">
                <div class="notify-form-wrap">
                    <h2>Instant Discounts & Latest Prizes!</h2>

                    <form id="notify-form" class="notify-form" action="#" method="POST">
                        <input type="email" name="email" autocomplete="email" required placeholder="email@youremail.com"/>
                        <button type="submit">Subscribe</button>
                    </form>
                </div>
            </div>

        <?php return ob_get_clean();
    }

    public function register_rest_api_routes()
    {
        register_rest_route('notify-gfni/v1', 'latest-products', array(
            'methods'  => 'GET',
            'callback' => array( $this, 'get_live_products')
        ));
        register_rest_route('notify-gfni/v1', 'subscribe', array(
            'methods'  => 'POST',
            'callback' => array( $this, 'shortcode_subscribe')
        ));
    }

    /**
     * Process the requests that comes to custom url.
     */
    public function get_live_products()
    {
        $query = array(
            'post_type' => 'product',
            'posts_per_page' => 60,
            'post_status' => 'publish',
            'meta_query' => array()
        );
        $wp_query = new WP_Query($query);
        $data = [];
        foreach ($wp_query->get_posts() as $post) {
            $item = [];
            $product = wc_get_product($post->ID);
            $item['id'] 			= $product->get_id();
            $item['title'] 			= $product->get_title();
            $item['price_html'] 	= $product->get_price_html();
            $item['image'] 	= get_the_post_thumbnail_url($post->ID);
            //$item['image'] 	= wp_get_attachment_image_url($post->ID, 'woocommerce_single');
            $item['price'] 	= $product->get_price();
            $item['url'] 	= get_permalink($post->ID);

            $data[] = $item;
        }

        if (empty($data)) {
            return new WP_Error('empty_category', 'there are no instock products', array('status' => 404));
        }

        $response = new WP_REST_Response($data);
        $response->set_status(200);

        return $response;
    }

    public function shortcode_subscribe()
    {
        $this->post_subscriber($_POST['email']);
    }

    public function post_subscriber($email, $firstName = '', $lastName ='')
    {
        $ch = curl_init('https://notify.getfoundni.co.uk/api/subscribe');
        $jsonDataEncoded = json_encode(array(
            'key' 			=> get_option('notify_settings_option_name')['key_0'],
            'email'			=> $email,
            'first_name'    => $firstName,
            'last_name'		=> $lastName
        ));

        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonDataEncoded);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 2);
        curl_setopt($ch, CURLOPT_TIMEOUT, 2);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));

        curl_exec($ch);
    }
}
